---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**HSSM version**
What is the version of HSSM you are using?

**To Reproduce**
Minimum reproducible code for us to reproduce the error.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Additional context**
Add any other context about the problem here, such as the print out of the model.
